@@ -3,7 +3,7 @@ from abc import ABC
 from enum import Enum
 from typing import List, Optional, Generator, Tuple, Dict
 
-from dstack.config import load_config, AwsBackendConfig, Config, BackendConfig
+from dstack.config import load_config, AwsBackendConfig, Config
 from dstack.jobs import Job, JobStatus, JobHead, AppSpec
 from dstack.repo import RepoData, RepoCredentials
 from dstack.runners import Resources, Runner
@@ -162,7 +162,7 @@ class Secret:
 
 
 class Backend(ABC):
-    def configure(self, silent: bool) -> bool:
+    def configure(self):
         pass
 
     def create_run(self, repo_user_name: str, repo_name: str) -> str:
