@@ -15,7 +15,7 @@ class AppHeadItem(BaseModel):
 
 class ArtifactHeadItem(BaseModel):
     job_id: str
-    artifact_name: str
+    artifact_path: str
 
 
 class RequestHeadItem(BaseModel):
@@ -43,7 +43,7 @@ class RunItem(BaseModel):
     repo_name: str
     repo_branch: str
     repo_hash: str
-    repo_diff: str
+    repo_diff: Optional[str]
     run_name: str
     workflow_name: Optional[str]
     provider_name: str
@@ -74,7 +74,7 @@ async def query(repo_user_name: str, repo_name: str) -> QueryRunsResponse:
             run_name=r.run_name,
             workflow_name=r.workflow_name,
             provider_name=r.provider_name,
-            artifacts=[ArtifactHeadItem(job_id=a.job_id, artifact_name=a.artifact_path)
+            artifacts=[ArtifactHeadItem(job_id=a.job_id, artifact_path=a.artifact_path)
                        for a in r.artifact_heads] if r.artifact_heads else None,
             status=r.status.value,
             submitted_at=r.submitted_at,
@@ -102,7 +102,7 @@ async def get(repo_user_name: str, repo_name: str, run_name: str) -> GetRunRespo
                 run_name=r.run_name,
                 workflow_name=r.workflow_name,
                 provider_name=r.provider_name,
-                artifacts=[ArtifactHeadItem(job_id=a.job_id, artifact_name=a.artifact_path)
+                artifacts=[ArtifactHeadItem(job_id=a.job_id, artifact_path=a.artifact_path)
                            for a in r.artifact_heads] if r.artifact_heads else None,
                 status=r.status.value,
                 submitted_at=r.submitted_at,
